@@ -44,7 +44,7 @@ class LIB:
                   special_chars: bool = False,
                   printable_chars: bool = False,
                   control_chars: bool = False
-                  ):
+                  ) -> str:
         index = 1
         key = ""
         literal = ""
@@ -77,12 +77,20 @@ class LIB:
             key = f"Impossivel gerar uma chave. Erro: {error}"
         return key
 
+    @staticmethod
+    def build_keys(qtd: int = 1) -> list:
+        keys = []
+        for index in range(qtd):
+            k = LIB.build_key()
+            keys.append(k)
+        return keys
+
     @staticmethod
     def hash(word: str, pattern: str = "md5"):
         pattern_list = ["md5", "sha1", "sha224", "sha256", "sha384", "sha512"]
         h, msg, error = None, None, None
         try:
-            #value = b'{word}'
+            #value /= b'{word}'/
             if pattern == pattern_list[0]:
                 h = hashlib.md5()
             elif pattern == pattern_list[1]:
@@ -337,6 +345,6 @@ class LIB:
 
 if __name__ == "__main__":
     x = LIB()
-    t = x.token_get("D@S@")
+    t = x.build_keys(100)
     print(t)
 
